from dataclasses import dataclass
from pathlib import Path
import json

@dataclass
class Config:
    host: str
    port: int

    # Path to the mpv binary
    mpv: str

    # Path to where the mpv IPC sock should be put
    mpv_ipc_sock: str

    # Extra args to pass to mpv
    mpv_args: list[str]

    # Wallpapers to show
    wallpapers: list[str]

    # Additional scripts to load
    scripts: dict[str, str]

def load_config(config_path: Path | None) -> Config:
    if config_path is None:
        config_data = {}
    else:
        with open(config_path, "r") as f:
            config_data = json.load(f)

    return Config(
        host=config_data.get("host", "0.0.0.0"),
        port=config_data.get("port", 8080),
        mpv=config_data.get("mpv", "/usr/bin/mpv"),
        mpv_ipc_sock=config_data.get("mpv_ipc_sock", "/tmp/mpv.sock"),
        mpv_args=config_data.get("mpv_args", []),
        wallpapers=config_data.get("wallpapers", []),
        scripts=config_data.get("scripts", {}),
    )
